import { Injectable, Directive, ElementRef, Input, Renderer2, NgModule } from '@angular/core';

/**
 * @fileoverview added by tsickle
 * Generated from: lib/ngx-truncate.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NgxTruncateService {
    constructor() { }
    /**
     * check the word cut
     * @param {?} number
     * @param {?} text
     * @return {?}
     */
    checkWordCut(number, text) {
        /** @type {?} */
        let i = 0;
        for (i = number; i < text.length; i++) {
            if (text[i] == ' ')
                break;
        }
        return text.substring(0, i);
    }
    /**
     * find hashtag from text
     * @param {?} text
     * @return {?}
     */
    findHashtag(text) {
        //text = text.replace(new RegExp(pattern, 'ugmi'), match => {
        text = text.replace(/^|[\s](#[\p{Pc}\p{N}\p{L}\u200cÀ-ÖØ-öø-ʸ(_)]+)/ugmi, (/**
         * @param {?} match
         * @return {?}
         */
        (match) => {
            return `<span class="hashtag" style="color:#1b95e0">${match}</span>`;
        }));
        return text;
    }
    /**
     * check conditions and return text with them
     * @param {?} text
     * @param {?} number
     * @param {?=} completeWord
     * @param {?=} hashtag
     * @return {?}
     */
    applyCondition(text, number, completeWord = false, hashtag = false) {
        /** @type {?} */
        let manipulatedText = "";
        if (completeWord && hashtag) {
            /** @type {?} */
            const temp = this.checkWordCut(number, text);
            manipulatedText = this.findHashtag(temp);
        }
        else if (completeWord) {
            manipulatedText = this.checkWordCut(number, text);
        }
        else if (hashtag) {
            /** @type {?} */
            const temp = text.substring(0, number);
            manipulatedText = this.findHashtag(temp);
        }
        else {
            manipulatedText = text.substring(0, number);
        }
        return manipulatedText;
    }
}
NgxTruncateService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
NgxTruncateService.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * Generated from: lib/ngx-truncate-text.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NgxTruncateTextDirective {
    /**
     * @param {?} elRef
     * @param {?} renderer
     * @param {?} trunService
     */
    constructor(elRef, renderer, trunService) {
        this.elRef = elRef;
        this.renderer = renderer;
        this.trunService = trunService;
        this.replace = false;
        ((/** @type {?} */ (window))).trun = this;
        // elRef will get a reference to the element where
        // the directive is placed
        this.element = elRef.nativeElement;
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        this.fill(this.element.innerHTML);
    }
    /**
     * @param {?} text
     * @return {?}
     */
    fill(text) {
        this.text = text;
        /** @type {?} */
        let remainText = "";
        if (text.length > this.number) {
            remainText = this.trunService.applyCondition(text, this.number, this.completeWord, this.hashtag);
            this.replace = true;
            this.element.innerHTML = remainText + ' ... ';
            /** @type {?} */
            const span = this.renderer.createElement('span');
            span.innerHTML = this.more;
            this.renderer.setStyle(span, 'color', '#ff00ff');
            this.renderer.setStyle(span, 'cursor', 'pointer');
            this.renderer.addClass(span, 'toggleText');
            this.renderer.listen(span, 'click', (/**
             * @param {?} event
             * @return {?}
             */
            (event) => this.replace === true ? this.showFullText(event) : this.hideSomeText(event)));
            this.element.appendChild(span);
        }
        else {
            this.element.innerHTML = this.hashtag ? this.trunService.findHashtag(text) : text;
        }
    }
    /*
      * نمایش کامل متن
      * @param mouseDown {mousedown} mouse event
      */
    /**
     * @param {?} mouseDown
     * @return {?}
     */
    showFullText(mouseDown) {
        /** @type {?} */
        const span = this.renderer.createElement('span');
        span.innerHTML = " " + this.less;
        this.renderer.setStyle(span, 'color', '#ff00ff');
        this.renderer.setStyle(span, 'cursor', 'pointer');
        this.renderer.addClass(span, 'toggleText');
        this.element.innerHTML = this.hashtag ? this.trunService.findHashtag(this.text) : this.text;
        this.renderer.listen(span, 'click', (/**
         * @param {?} event
         * @return {?}
         */
        (event) => this.hideSomeText(event)));
        this.element.appendChild(span);
        // جلوگیری از کلیک روی عنصر پدر
        mouseDown.stopPropagation();
        this.replace = false;
    }
    /*
       * نمایش قسمتی از متن بر اساس تعداد کاراکتر خواسته شده
       * @param mouseDown {mousedown} mouse event
       */
    /**
     * @param {?} mouseDown
     * @return {?}
     */
    hideSomeText(mouseDown) {
        /** @type {?} */
        const remainText = this.trunService.applyCondition(this.text, this.number, this.completeWord, this.hashtag);
        /** @type {?} */
        const span = this.renderer.createElement('span');
        this.renderer.setStyle(span, 'color', '#ff00ff');
        this.renderer.setStyle(span, 'cursor', 'pointer');
        this.renderer.addClass(span, 'toggleText');
        span.innerHTML = this.more;
        this.element.innerHTML = remainText + ' ... ';
        this.renderer.listen(span, 'click', (/**
         * @param {?} event
         * @return {?}
         */
        (event) => this.showFullText(event)));
        this.element.appendChild(span);
        // جلوگیری از کلیک روی عنصر پدر
        mouseDown.stopPropagation();
        this.replace = true;
    }
}
NgxTruncateTextDirective.decorators = [
    { type: Directive, args: [{
                selector: '[ngxTruncateText]'
            },] }
];
/** @nocollapse */
NgxTruncateTextDirective.ctorParameters = () => [
    { type: ElementRef },
    { type: Renderer2 },
    { type: NgxTruncateService }
];
NgxTruncateTextDirective.propDecorators = {
    more: [{ type: Input }],
    less: [{ type: Input }],
    number: [{ type: Input }],
    completeWord: [{ type: Input }],
    hashtag: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * Generated from: lib/ngx-truncate-text.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NgxTruncateTextModule {
}
NgxTruncateTextModule.decorators = [
    { type: NgModule, args: [{
                declarations: [NgxTruncateTextDirective],
                imports: [],
                exports: [NgxTruncateTextDirective],
                providers: [NgxTruncateService]
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: public-api.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: ngx-truncate-text.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { NgxTruncateTextModule, NgxTruncateTextDirective, NgxTruncateService as ɵa };

//# sourceMappingURL=ngx-truncate-text.js.map